Index: include/gpu/GrContext.h |
diff --git a/include/gpu/GrContext.h b/include/gpu/GrContext.h |
index f9d06f097a679bc9f12826d185e2af00fc2b6194..daaf90687c4c2edeac836a4e27946a6dee322abc 100644 |
--- a/include/gpu/GrContext.h |
+++ b/include/gpu/GrContext.h |
@@ -441,8 +441,8 @@ private: |
GrAuditTrail fAuditTrail; |
- // TODO: have the CMM use drawContexts and rm this friending |
- friend class GrClipMaskManager; // the CMM is friended just so it can call 'drawingManager' |
+ // TODO: have the ClipStackClip use drawContexts and rm this friending |
+ friend class GrClipStackClip; // this is friended just so it can call 'drawingManager' |
friend class GrDrawingManager; // for access to drawingManager for ProgramUnitTest |
GrDrawingManager* drawingManager() { return fDrawingManager; } |